# Optimize Rosenbrock function with differential evolution
# Collect cost function and plot progress

from pyopus.optimizer.de import DifferentialEvolution
from pyopus.optimizer import glbctf
from pyopus.optimizer.base import Reporter
from pyopus.evaluator.cost import CostCollector
import pyopus.wxmplplot as pyopl
from numpy import array, zeros, arange

if __name__=='__main__':
	ndim=30
	popSize=50
	
	prob=glbctf.Rosenbrock(n=ndim)
	
	opt=DifferentialEvolution(
		prob, prob.xl, prob.xh, debug=0, 
		maxGen=1500, populationSize=popSize, w=0.5, pc=0.3
	)
	cc=CostCollector()
	opt.installPlugin(cc)
	opt.installPlugin(Reporter(onIterStep=1000))
	opt.reset()
	opt.run()
	cc.finalize()
	
	pyopl.init()
	pyopl.figure()
	pyopl.subplot(1,1,1)
	pyopl.semilogy(arange(len(cc.fval))/popSize, cc.fval)
	pyopl.xlabel('generations')
	pyopl.ylabel('f')
	pyopl.title('Progress of differential evolution')
	pyopl.grid()
	
	print("x=%s f=%e" % (str(opt.x), opt.f))
	