import pyopus.wxmplplot as pyopl
from numpy import arange, sin, cos, exp, pi, e

if __name__ == '__main__':
	# Initialize gui thread, clean up. 
	pyopl.init()
	pyopl.closeAllFigures()

	# Plot data - sin(x), cos(x), exp(x/pi) .. for x in [0, 2pi] with 0.2 step. 
	x = arange(0.0, 2*pi, 0.2)
	y1 = sin(x)
	y2 = cos(x)
	y3 = exp(x/pi)

	# Create first figure (plot window). This is now the active figure. 
	# Tag is assigned automatically by the system. 
	f1=pyopl.figure(None, windowTitle="Figure - single axes", figpx=(600,400), dpi=100)	
	print("Figure tag: "+str(f1))
	
	# Disable active figure updates while we are preparing its contents. 
	pyopl.repaintFigure(False)
	
	# Create axes in active figure. Axes will take the whole area of the active figure. 
	# Return vaslue is the tag for these axes. The tag is generated by the system . 
	ax1=pyopl.axes()
	print("Axes tag: "+str(ax1)) 
	
	# Add first trace (x, y1). 
	# Solid line, points marked with o. 
	# Color is a (r,g,b) tuple. 
	# Label it 'sin(x)'. 
	# See matplotlib for style options. 
	# Arguments are passed on to matplotlib. 
	pyopl.plot(x, y1, '-o', label='sin(x)', color=(1,0,0))
	
	# Hold on - next traces will not delete previous ones. 
	pyopl.hold(True)
	
	# Add second trace. 
	# Red, points marked with x, no line. 
	pyopl.plot(x, y2, 'rx', label='cos(x)')
	
	# Add third trace
	# Dashed, black, points marked with vertical lines. 
	pyopl.plot(x, y3, '--k|', label='exp(x/pi)')
	
	# Add legend. 
	pyopl.legend()
	
	# Label axes, add title. 
	pyopl.xlabel('x-axis')
	pyopl.ylabel('y-axis')
	pyopl.title('Axes title. ')
	
	# Get tag of active figure. 
	tag0=pyopl.getFigure()
	print("Active figure: "+str(tag0))
	
	# Get tag of active axes for active figure. 
	axtag0=pyopl.getAxes()
	print("Active axes in active figure: "+str(axtag0))
	
	# Turn on grid. 
	pyopl.grid(True)
	
	# Figure title. 
	pyopl.figureTitle("Figure title")
	
	# Disable hold. We are done adding new traces. 
	pyopl.hold(False)
	
	# Enable active figure updates. 
	pyopl.repaintFigure(True)
