import pyopus.wxmplplot as pyopl
from numpy import arange, sin, cos, exp, pi, e

if __name__ == '__main__':
	# Initialize gui thread, clean up. 
	pyopl.init()
	pyopl.closeAllFigures()

	# Plot data - sin(x), cos(x), exp(x/pi) .. for x in [0, 2pi] with 0.2 step. 
	x = arange(0.0, 2*pi, 0.2)
	y1 = sin(x)
	y2 = cos(x)
	y3 = exp(x/pi)
	
	# Plot window
	f1=pyopl.figure("fig1", windowTitle="Manually sized subplots", figpx=(600,600), dpi=100)
	
	# Disable repainting
	pyopl.repaintFigure(False)
	
	# Create 2 subplots, vertical stack of 2, 40%+60% height
	# (x0, y0, w, h) ... 
	#   x=0 .. left,  y=0 .. bottom
	#   x=1 .. right, y=1 .. top 
	ax1=pyopl.axes((0.1,0.1,0.8,0.25)) # 10% left, right, and bottom margin, 5% top margin
	ax2=pyopl.axes((0.1,0.45,0.8,0.45)) # 10% left, right, and top margin, 5% bottom margin
	
	# First axes
	pyopl.setAxes(ax1)
	pyopl.hold(True)
	pyopl.plot(x, y1, '-o', label='sin(x)', color=(1,0,0))
	pyopl.plot(x, 2*y1, '-o', label='2sin(x)', color=(1,0,0))
	pyopl.grid(True)
	pyopl.xlabel('x')
	pyopl.ylabel('sin(x), 2sin(x)')
	# Titles on vertically stacked axes are a bad idea, because they overlap with x-axis labels. 
	pyopl.title('Axes 1')
	pyopl.hold(False)
	
	# Second axes
	pyopl.setAxes(ax2)
	pyopl.hold(True)
	pyopl.plot(x, y1, '-', label='sin(x)', color=(1,0,0))
	pyopl.plot(x, y2, '-', label='cos(x)', color=(0,1,0))
	pyopl.grid(True)
	pyopl.xlabel('x')
	pyopl.ylabel('sin(x), cos(x)')
	pyopl.title('Axes 2')
	pyopl.hold(False)
	
	# Add  figure title
	pyopl.figureTitle("Axes scaling with %")
	
	# Enable repainting
	pyopl.repaintFigure(True)
