import pyopus.wxmplplot as pyopl
from numpy import arange, sin, cos, exp, pi, e

if __name__ == '__main__':
	# Initialize gui thread, clean up. 
	pyopl.init()
	pyopl.closeAllFigures()

	# Plot data - sin(x), cos(x), exp(x/pi) .. for x in [0, 2pi] with 0.2 step. 
	x = arange(0.0, 2*pi, 0.2)
	y1 = sin(x)
	y2 = cos(x)
	y3 = exp(x/pi)
	
	# Plot window
	f1=pyopl.figure("fig1", windowTitle="Scaling", figpx=(800,400), dpi=100)
	
	# Disable repainting
	pyopl.repaintFigure(False)
	
	# Create 2 subplots, horizontal stack of 2
	ax1=pyopl.subplot(1,2,1)
	ax2=pyopl.subplot(1,2,2)
	
	# First axes
	pyopl.setAxes(ax1)
	pyopl.hold(True)
	pyopl.plot(x, y1, '-o', label='sin(x)', color=(1,0,0))
	pyopl.plot(x, 2*y1, '-o', label='2sin(x)', color=(1,0,0))
	pyopl.grid(True)
	pyopl.xlabel('x')
	pyopl.ylabel('sin(x), 2sin(x)')
	pyopl.title('y limits = autoscale + 20%')
	
	# Get y limits
	yl=pyopl.getYlim()
	print("y limits: "+str(yl))
	# Limits are set as two positional arguments, expand by 20%
	pyopl.setYlim(yl[0]*1.2, yl[1]*1.2)
	
	pyopl.hold(False)
	
	# Second axes
	pyopl.setAxes(ax2)
	pyopl.hold(True)
	pyopl.plot(x, y1, '-', label='sin(x)', color=(1,0,0))
	pyopl.plot(x, y2, '-', label='cos(x)', color=(0,1,0))
	pyopl.grid(True)
	pyopl.xlabel('x')
	pyopl.ylabel('sin(x), cos(x)')
	pyopl.title('Manual x,y scale, then autoscale y')
	
	# Set x limits
	pyopl.setXlim(3.5, 4.5)
	pyopl.setYlim(-2.0, 2.0)
	# Autoscale only y
	pyopl.autoscale(scalex=False, scaley=True)
	
	pyopl.hold(False)
	
	# Enable repainting
	pyopl.repaintFigure(True)
