import pyopus.wxmplplot as pyopl
from numpy import arange, sin, cos, exp, pi, e

if __name__ == '__main__':
	# Initialize gui thread, clean up. 
	pyopl.init()
	pyopl.closeAllFigures()

	# Plot data - sin(x), cos(x), exp(x/pi) .. for x in [0, 2pi] with 0.2 step. 
	t = arange(0.0, 10*pi, 0.2)
	r = 100/(10+t)
	y = sin(t)*r
	x = cos(t)*r
	
	# Plot window
	f1=pyopl.figure("fig1", windowTitle="xy and polar plot", figpx=(800,400), dpi=100)
	
	# Disable repainting
	pyopl.repaintFigure(False)
	
	# Create 2 subplots, horizontal stack of 2
	ax1=pyopl.subplot(1,2,1, aspect='equal')	# Equal aspect ratio
	ax2=pyopl.subplot(1,2,2, aspect='equal', projection='polar')	# Equal aspect ratio, polar plot
	
	# First axes
	pyopl.setAxes(ax1)
	pyopl.hold(True)
	pyopl.plot(x, y, '-', label='sin(x)', color=(1,0,0))
	pyopl.grid(True)
	pyopl.xlabel('x')
	pyopl.ylabel('y')
	pyopl.title('Equal aspect ratio, x-y plot')
	pyopl.hold(False)
	
	# Second axes
	pyopl.setAxes(ax2)
	pyopl.hold(True)
	pyopl.plot(t, r, '-', label='r=r(t)', color=(1,0,0))
	pyopl.grid(True)
	
	# Get r limits
	rl=pyopl.getRlim()
	print("R limits: "+str(rl))
	# Expand by 20%
	pyopl.setRlim(rl*1.2)
	
	pyopl.title('Equal aspect ratio, polar plot r=r(t)')
	pyopl.hold(False)
	
	# Enable repainting
	pyopl.repaintFigure(True)
