import pyopus.wxmplplot as pyopl
from numpy import arange, sin, cos, exp, pi, e

if __name__ == '__main__':
	# Initialize gui thread, clean up. 
	pyopl.init()
	pyopl.closeAllFigures()

	# Plot data - sin(x), cos(x), exp(x/pi) .. for x in [0, 2pi] with 0.2 step. 
	t = arange(0.0, 10*pi, 0.2)
	r = 2*pi/(2*pi+t)
	y = sin(t)*r
	x = cos(t)*r
	
	# Plot window
	f1=pyopl.figure("fig1", windowTitle="Annotations", figpx=(800,400), dpi=100)
	
	# Disable repainting
	pyopl.repaintFigure(False)
	
	# Create 2 subplots, horizontal stack of 2
	ax1=pyopl.subplot(2,1,1) 
	ax2=pyopl.subplot(2,1,2) 
	
	# First axes
	pyopl.setAxes(ax1)
	pyopl.hold(True)
	pyopl.plot(t, x, '-', label='cos(t)*r(t)', color=(1,0,0))
	pyopl.plot(t, y, '-', label='sin(t)*r(t)', color=(0,0.5,0))
	pyopl.grid(True)
	pyopl.xlabel('t')
	pyopl.ylabel('x(t), y(t)')
	# Add legend
	pyopl.legend()
	# Add manual x grid lines
	pyopl.xgridline(2*pi, color=(1,0.5,0.5), linewidth=0.5)
	pyopl.xgridline(4*pi, color=(1,0.5,0.5), linewidth=0.5)
	pyopl.xgridline(6*pi, color=(1,0.5,0.5), linewidth=0.5)
	pyopl.xgridline(8*pi, color=(1,0.5,0.5), linewidth=0.5)
	pyopl.xgridline(10*pi, color=(1,0.5,0.5), linewidth=0.5)
	pyopl.hold(False)
	
	# Second axes
	pyopl.setAxes(ax2)
	pyopl.hold(True)
	pyopl.plot(t, r, '-', label='r=r(t)', color=(1,0,0))
	pyopl.grid(True)
	pyopl.xlabel('t')
	pyopl.ylabel('r(t)')
	# Add text, x and y coordinates are in scale units
	# Backslashes in LaTeX markup must be escaped (double backslashes)
	pyopl.text(20, 0.5, 'Look mom, a fraction! $a \\cdot b = \\frac{t}{sin(x)}$', backgroundcolor=(1,1,1))
	pyopl.text(2*pi, 0.75, 'Magnitude: $r(t)=2\\pi(2\\pi+t)^{-1}$')
	# Add annotation with arrow
	# First point is the arrowhead point.
	# Second point is the text position. 
	pyopl.annotate('50th point of r(t)', (t[49], r[49]), (20.0, 0.8), 
			arrowprops={'width': 0.1, 'shrink': 0.05, 'headwidth': 4, 'edgecolor': '#1010ff', 'facecolor': '#0000ff'}
	)
	pyopl.hold(False)
	
	# Enable repainting
	pyopl.repaintFigure(True)
