import pyopus.wxmplplot as pyopl
from numpy import arange, sin, cos, exp, pi, e

if __name__ == '__main__':
	# Initialize gui thread, clean up. 
	pyopl.init()
	pyopl.closeAllFigures()

	# Plot data - sin(x), cos(x), exp(x/pi) .. for x in [0, 2pi] with 0.2 step. 
	x = arange(0.0, 2*pi, 0.2)
	y1 = sin(x)
	y2 = cos(x)
	y3 = exp(x/pi)

	# Create figure. Tag is assigned automatically by the system. Do not show it. 
	f1=pyopl.figure(None, windowTitle="Figure - single axes", show=False, figpx=(600,400), dpi=100)	
	
	# Disable active figure updates while we are preparing its contents. 
	pyopl.repaintFigure(False)
	
	# Create axes in active figure. 
	ax1=pyopl.axes()
	
	# Add traces, legend, labels, axes title, grid, figure title
	pyopl.plot(x, y1, '-o', label='sin(x)', color=(1,0,0))
	pyopl.hold(True)
	pyopl.plot(x, y2, 'rx', label='cos(x)')
	pyopl.plot(x, y3, '--k|', label='exp(x/pi)')
	pyopl.legend()
	pyopl.xlabel('x-axis')
	pyopl.ylabel('y-axis')
	pyopl.title('Axes title. ')
	pyopl.grid(True)
	pyopl.figureTitle("Figure title")
	pyopl.hold(False)
	
	# Enable active figure updates. 
	pyopl.repaintFigure(True)
		
	# Figure is still invisible, save it as png. 
	# Size will be the figure size in pixels given by figpx 
	# (if not given, calculated from figsize and dpi). 
	pyopl.saveFigure("demo.png", f1)
	
	# Save it as eps
	# Size will be figure size in inches given by figsize
	# (if not given, calculated from figpx and dpi). 
	pyopl.saveFigure("demo.eps", f1)
	
	# Now show and raise figure
	pyopl.showFigure(True, f1)
	pyopl.raiseFigure(f1)
	
	# Save again
	pyopl.saveFigure("demo-visible.png", f1)
	pyopl.saveFigure("demo-visible.eps", f1)
	
	# Close figure
	pyopl.closeFigure(f1)
	
	# Shut down plot gui. This way the user does not have to 
	# close the control window manually. 
	pyopl.shutdown()
	
